# pivot.py

import pandas as pd
from importlib_resources import files

def load_word():
	scfile = files('wordjc.data').joinpath('web4.csv')
	return pd.read_csv(scfile)

def bible_stat(df):
	stat_df = pd.pivot_table(df, index=['book_no', 'book', 'category', 'cat_no'],
                          values=['chapter', 'verse', 'text'],
                          aggfunc={'chapter': lambda ch: len(ch.unique()),
                                   'verse': 'count',
                                   'text': lambda ts: sum([len(t.split()) for t in ts])})
	stat_df = stat_df[['chapter', 'verse', 'text']].sort_index()

	stat_df2 = stat_df.groupby('cat_no').apply(lambda sub: sub.pivot_table(
                        index=['category', 'book_no', 'book'],
                        values=['chapter', 'verse', 'text'],
                        aggfunc={'chapter': 'sum',
                                 'verse': 'sum',
                                 'text': 'sum'},
                        margins=True,
                        margins_name='Sub-Total'))

	stat_df2.loc[('', '', 'Total', '')] = stat_df2.sum() // 2
	stat_df2.index = stat_df2.index.droplevel(0)
	stat_df2.fillna('', inplace=True)
	stat_df2 = stat_df2[['chapter', 'verse', 'text']]
	return stat_df2



# load.py

import numpy as np
import pandas as pd
from importlib_resources import files
import re
import nltk
from nltk.corpus import stopwords
import matplotlib.pyplot as plt
from wordcloud import WordCloud
from PIL import Image

def load_word():
    scfile = files('wordjc.data').joinpath('web4.csv')
    return pd.read_csv(scfile)

def clean_text(df):
    df.text = [re.sub(r'\d+', '', str(v).replace('\n', ' ')) for v in df.text]
    for sw in stopwords.words('english'):
        df.text = [v.replace(' ' + sw + ' ', ' ') for v in df.text]

    df.text = df.text.apply(lambda v: " ".join(w.lower() for w in v.split()))
    df.text = df.text.str.replace('[^\w\s]', '', regex=True)
    return df

def plot_cloud(wordcloud):
    plt.figure(figsize=(15, 10))
    plt.imshow(wordcloud) 
    plt.axis("off");

def show_wordcloud(text, image=None, mask=None):
    if image:
        mask = np.array(Image.open(image))

    wordcloud = WordCloud(background_color='black', colormap='Set2', mask=mask) \
                    .generate(text)

    plot_cloud(wordcloud)
